"""
timereport tags
---------------

.. autofunction:: status_class

.. autofuncion:: create_legend

::

  {% load ttags %}

  {{ transit.status|status_class:transit.accepted }}


"""

from django import template

from timereport import models


register = template.Library()

@register.filter
def status_class(code, accepted=None):
    """Ritorna la classe css corrispondente allo stato di un transito

    :param code: Reason.codeil numero intero preso da timereport.models.STATUS_CODES
    :param accepted: (bolean) if True is a holiday to be accepted
    """
    class_ = ''
    for obj in models.Reason.objects.all():
        if code == obj.code:
            class_ = obj.description.lower()
        if code == 'H' and not accepted:
            class_ = "holiday_to_be_confirmed"
    return class_

        
@register.filter
def create_legend(junk):
    "Create a legend of the fields in table reason"

    HTML =   """<div class="voce_legenda"><div class="box" style="background-color: %s"></div>%s
         <div class="box_testo">%s</div><div class="clear"></div></div>"""

    txt = []
    for reason in models.Reason.objects.filter(status=1).order_by('odv'):
        if reason.in_legend:
            if reason.approval_required :
                box2='<div class="to_approve box" style="background-color: %s"></div>' % reason.color
            else:
                box2 = ''
            txt += [HTML % (reason.color  or '', box2, reason.description)]

    return "\n".join(txt)
    
create_legend.is_safe = True

@register.filter
def transit_status(transit):
    "if the transit is to be approved, return 'to_approve' class"

    if transit.period and transit.period.status:
        print t, 'to_approve'
        return "to_approve"
    return ""

