import os
import datetime
from django.test import TestCase, Client
from django.conf import settings
from jumbo import conf

from timereport.templatetags import ttags
from timereport import models

class AnonTest(TestCase):
    def test_01_model(self):
        "verify model doesn't break import"

        from jumbo.conf.urls import JUMBO_URL
        assert True
    

class TagTests(TestCase):

    fixtures = ['timereport.yaml']

    def setUp(self):
        #self.client = Client()
        conf.set_interactive_user('admin')
        self.client.login(username='admin', password='testpwd')

    def test_01_status_code(self):
        "Primo test di prova"
        
        assert ttags.status_class('P', True) == 'permit'
        assert ttags.status_class('ILL', True) == 'illness'
        assert ttags.status_class('H', True) == 'holiday'
        assert ttags.status_class('', True) == ''
        assert ttags.status_class('H', False) == 'holiday_to_be_confirmed'

    def test_02_holiday_period(self):
        "get_days senza sab/dom"
        
        from timereport.forms import VacationPeriodForm

        post_dict = {'start_date'  : datetime.date(2012,4,10),
                     'end_date'    : datetime.date(2012,4,13),
                     'employee'    : 0,
                     'reason'    : 'H',
                     }
        form = VacationPeriodForm(post_dict)
        assert form.is_valid()
        assert form.get_working_days() == [
            datetime.date(2012,4,10),
            datetime.date(2012,4,11),
            datetime.date(2012,4,12),
            datetime.date(2012,4,13),
            ]

    def test_03_vacation_period(self):
        "get_days con sab/dom"
        
        from timereport.forms import VacationPeriodForm

        post_dict = {'start_date'  : datetime.date(2012,4,20),
                     'end_date'    : datetime.date(2012,4,23),
                     'employee'    : 0,
                     'reason'    : 'H',
                     }
        form = VacationPeriodForm(post_dict)
        assert form.is_valid()
        assert form.get_working_days() == [
            datetime.date(2012,4,20),
            datetime.date(2012,4,23),
            ]

    def test_04_vacation_period(self):
        "get_days con sab/dom"
        
        from timereport.forms import VacationPeriodForm

        post_dict = {'start_date'  : datetime.date(2012,4,21),
                     'end_date'    : datetime.date(2012,4,24),
                     'employee'    : 0,
                     'reason'    : 'H',
                     }
        form = VacationPeriodForm(post_dict)
        assert form.is_valid()
        assert form.get_working_days() == [
            datetime.date(2012,4,23),
            datetime.date(2012,4,24),
            ]

    def test_05_color_H(self):
        "Check that color is present"
        h = models.Reason.objects.get(pk='H')
        assert h.color
        assert h.in_legend is True

class PoolTest(TestCase):
    fixtures = ['timereport.yaml']
    __test__= False
    
    def setUp(self):
        self.client = Client()
        conf.set_interactive_user('admin')
        self.client.login(username='admin', password='testpwd')

    def test_01_aggiungi_periodo(self):
        "Aggiungi un periodo di ferie"

        response = self.client.get(
            '/admin/timereport/period/add_vacation/',)
        self.failUnlessEqual(response.status_code, 200)

#     # def test_01_aggiungi_periodo(self):
#     #     "Aggiungi un periodo di ferie"

#     #     post_dict = {'start_date'  : datetime.date(2012,4,10),
#     #                  'end_date'    : datetime.date(2012,4,13),
#     #                  'employee'    : 0,
#     #                  }
#     #     response = self.client.post(
#     #         '/admin/timereport/period/add_vacation/', post_dict)
#     #     assert True
#     #     #self.failUnlessEqual(response.status_code, 200)
        
        
