# -*- coding: utf-8 -*-
from datetime import datetime, time, date, timedelta
import calendar

from django.http import HttpResponse, HttpResponseRedirect, HttpResponseNotFound, HttpResponseForbidden
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext

from jumbo.core.urlresolvers import reverse
from jumbo.utils.functions import get_settings
from jumbo.shortcuts import render_to_response, render_to_string

from timereport.models import Employee, Transit, TimeProfile
from timereport.exception import TransitException
from timereport.forms import TransitForm, PermitForm
from timereport.forms import VacationPeriodForm


def transit_add_visual(request):
    user = request.user
    small_view = False
    errors = []
    messages = []
    employee = None

    auth_by_badge = get_settings('timereport.settings', 'TIMEREPORT_AUTHENTICATED_BY_BADGE')
    time_refresh = get_settings('timereport.settings', 'TIMEREPORT_TIME_REFRESH')

    if request.GET.has_key('small_view'):
        small_view = True

    if request.method == 'POST':
        if auth_by_badge:
            try:
                employee = Employee.active_objects.get(badge=request.POST.get('badge', None))
            except:
                errors.append(_("The badge has no user associated with."))

        else:
            try:
                employee = Employee.active_objects.get(user=user)
            except:
                errors.append(_("No user found."))

        if employee:
            if request.POST.has_key('in'):
                try:
                    employee.add_in_transit()
                    messages.append(_("Welcome %(user)s. You enter at %(orario)s") % {
                                                        'user': employee.name,
                                                        'orario': datetime.today().strftime("%H:%M")}
                                   )
                except TransitException, e:
                    errors.append(e.value)
                except Exception, e:
                    errors.append("ERRORE IMPREVISTO. %s. Contattare l'amministratore." % e)

            if request.POST.has_key('out'):
                try:
                    employee.add_out_transit()
                    messages.append(_("Goodbye %(user)s. You go home at %(orario)s") % {
                                                        'user': employee.name,
                                                        'orario': datetime.today().strftime("%H:%M")}
                                    )
                except TransitException, e:
                    errors.append(e.value)
                except Exception, e:
                    errors.append("ERRORE IMPREVISTO. Contattare l'amministratore")

    if small_view:
        template_name = 'admin/timereport/transit_add_small.html'
    else:
        template_name = 'admin/timereport/transit_add_full.html'
    return render_to_response(template_name, errors=errors, app_label='timereport',
                              messages=messages, auth_by_badge=auth_by_badge, time_refresh=time_refresh)


def transit_add_permit(request):
    if request.method == 'POST':
        form = PermitForm(request.POST)
        if form.is_valid():
            try:
                form.save()
            except TransitException, e:
                return render_to_response("generic_error.html", error=e)
            return HttpResponseRedirect(reverse('admin:timereport_transit_calendar'))
    else:
        form = PermitForm()
    return render_to_response("admin/timereport/transit_add_manual.html", form=form,
                              app_label='timereport', title_form=_('Add Permit'))

# def transit_add_vacation(request):
#     if request.method == 'POST':
#         form = VacationForm(request.POST)
#         if form.is_valid():
#             try:
#                 form.save()
#             except TransitException, e:
#                 return render_to_response("jumbo/generic_error.html", error=e)
#             return HttpResponseRedirect(reverse('admin:timereport_transit_calendar'))
#     else:
#         form = VacationForm()
#     return render_to_response("admin/timereport/transit_add_manual.html", form=form,
#                               app_label='timereport', title_form=_('Add Vacation'))

def period_add_vacation(request):

    if request.method == 'POST':
        form = VacationPeriodForm(request.POST)
        if form.is_valid():
            try:
                form.save()
            except TransitException, e:
                return render_to_response("jumbo/generic_error.html", error=e)
            return HttpResponseRedirect(reverse('admin:timereport_transit_calendar'))
    else:
        form = VacationPeriodForm()
    return render_to_response("admin/timereport/period_add_manual.html", form=form,
                              app_label='timereport', title_form=_('Add Vacation'))


def transit_add_illness(request):
    if request.method == 'POST':
        form = IllnessForm(request.POST)
        if form.is_valid():
            try:
                form.save()
            except TransitException, e:
                return render_to_response("jumbo/generic_error.html", error=e)
            return HttpResponseRedirect(reverse('admin:timereport_transit_calendar'))
    else:
        form = IllnessForm()
    return render_to_response("admin/timereport/transit_add_manual.html", form=form,
                              app_label='timereport', title_form=_('Add Illness'))


def transit_add_injury(request):
    if request.method == 'POST':
        form = InjuryForm(request.POST)
        if form.is_valid():
            try:
                form.save()
            except TransitException, e:
                return render_to_response("jumbo/generic_error.html", error=e)
            return HttpResponseRedirect(reverse('admin:timereport_transit_calendar'))
    else:
        form = InjuryForm()
    return render_to_response("admin/timereport/transit_add_manual.html", form=form,
                              app_label='timereport', title_form=_('Add Injury'))
