# -*- coding: utf-8 -*-
from datetime import datetime, date, timedelta

from django.db.models import Q
from django.http import HttpResponseForbidden
#from django.contrib.auth.decorators import login_required

from jumbo.shortcuts import render_to_response, render_to_string
from jumbo.utils.functions import render_csv
from jumbo.middleware.thread_local import get_current_user

from timereport.forms import DownloadTransitForm
from timereport.models import Transit, Employee
from timereport.utils import Day, EmployeeProperty


def transit_download(request):
    if not request.user.has_perm("timereport.can_download_report_transit"):
        return HttpResponseForbidden(render_to_string('jumbo/forbidden.html'))

    if request.method == 'POST':
        form = DownloadTransitForm(request.POST)
        if form.is_valid():
            if request.POST.has_key('download_dettaglio'):
                return transit_download_dettaglio(form)
            elif request.POST.has_key('download_totale'):
                return transit_download_totale(form)
    else:
        form = DownloadTransitForm()

    return render_to_response("admin/timereport/transit_download.html",
                              app_label="timereport", form=form, title="DOWNLOAD TRANSITI")


def transit_download_dettaglio(form):
    user = get_current_user()

    if not user.has_perm("timereport.can_download_report_transit"):
        return HttpResponseForbidden(render_to_string('jumbo/forbidden.html'))

    date_begin = form.cleaned_data['date_begin']
    date_end = form.cleaned_data['date_end'] + timedelta(1)

    transits = Transit.objects.filter(
        date_time_in__gte = date_begin,
        date_time_in__lt = date_end
    ).filter(
        Q(date_time_out__lt = date_end) | Q(date_time_out__isnull = True)
    ).order_by('employee', 'date_time_in')

    max_len = 0
    rows = []
    day = None
    employee_id = None
    date_in = None

    for t in transits:
        d = t.date_time_in.date()
        if not (employee_id == t.employee.id and date_in == d):
            if day:
                ## appendo riga precedente se non vuota (avviene solo inizio)
                rows.append(day)

            ## creao nuova riga
            day = Day(d)
            day.add_transit(t)

            employee_id = t.employee.id
            date_in = d
        else:
            ## appendo nuova colonna
            day.add_transit(t)

        if len(day.transits) > max_len:
            max_len = day.get_num_transits()

    ## appendo ultima riga
    rows.append(day)

    csv_rows = []
    header = ['COGNOME NOME','MATRICOLA','DATA']
    header.extend(['INGRESSO', 'USCITA', 'PARZIALE'] * max_len)
    header.extend(['TOTALE', '\n'])
    csv_rows.append(';'.join(header))

    for day in rows:
        total = timedelta()
        csv_row = [day.get_first_transit().employee.name, '', day.get_first_transit().date_time_in.date().__str__()]
        for transit in day.transits:
            if transit.date_time_in:
                csv_row.append(transit.date_time_in.time().strftime('%H:%M'))
            else:
                csv_row.append("ERRORE")
            if transit.date_time_out:
                csv_row.append(transit.date_time_out.time().strftime('%H:%M'))
            else:
                csv_row.append("ERRORE")
            if transit.date_time_in and transit.date_time_out:
                csv_row.append(transit.duration.__str__())
                total += transit.duration
            else:
                csv_row.append("ERRORE")

        add_cols = max_len - day.get_num_transits()
        csv_row.extend(['']*add_cols*3)
        csv_row.extend([total.__str__(), '\n'])
        csv_rows.append(';'.join(csv_row))
    return render_csv(''.join(csv_rows), 'ore_%s_%s.csv' % (date_begin.strftime("%d/%m/%Y"), date_end.strftime("%d/%m/%Y")))


def transit_download_totale(form):
    user = get_current_user()

    if not user.has_perm("timereport.can_download_report_transit"):
        return HttpResponseForbidden(render_to_string('jumbo/forbidden.html'))

    date_begin = form.cleaned_data['date_begin']
    date_end = form.cleaned_data['date_end']

    employees = Employee.objects.all()
    csv_rows = []
    header = ['COGNOME NOME',]

    for i, employee in enumerate(employees):
        csv_row_ord = []
        csv_row_str = []
        curr_date = date_begin
        csv_row_ord.append(employee.name)
        csv_row_str.append('')
        while True:
            if curr_date > date_end:
                break

            if i == 0:
                header.append("%s" % curr_date.strftime("%d%a"))

            total_time_ord = '-'
            total_time_str = '-'

            total_time = employee.get_total_transit_time(curr_date)
            ord_duration = employee.get_ordinary_duration(curr_date)

            if not total_time == timedelta(0):
                total_time_ord = total_time.__str__()[:-3]
                if total_time > ord_duration:
                    total_time_ord = ord_duration.__str__()[:-3]
                    total_time_str = (total_time - ord_duration).__str__()[:-3]
            else:
                # controllo se c'e una malattia/ferie/infortunio
                total_time_ord = employee.get_status_absence(curr_date) or '-'

            csv_row_ord.append(total_time_ord)
            csv_row_str.append(total_time_str)
            curr_date += timedelta(1)

        csv_row_ord.append('\n')
        csv_rows.append(';'.join(csv_row_ord))
        csv_row_str.append('\n\n')
        csv_rows.append(';'.join(csv_row_str))

    header.append('\n')
    csv_rows.insert(0, ';'.join(header))

    return render_csv(''.join(csv_rows), 'ore_%s_%s.csv' % (date_begin.strftime("%d/%m/%Y"), date_end.strftime("%d/%m/%Y")))
